lpc: Rename point_to_flash lpc_map_flash

Change-Id: Id4f28611fed387c35e23acc3ec824e395e097202
Signed-off-by: Andrew Jeffery <andrew@aj.id.au>
diff --git a/lpc.c b/lpc.c
index a260c78..a2fc6e6 100644
--- a/lpc.c
+++ b/lpc.c
@@ -93,12 +93,12 @@
 }
 
 /*
  * point_to_flash() - Point the lpc bus mapping to the actual flash device
  * @context:	The mbox context pointer
  *
  * Return:	0 on success otherwise negative error code
  */
-int point_to_flash(struct mbox_context *context)
+int lpc_map_flash(struct mbox_context *context)
 {
 	struct aspeed_lpc_ctrl_mapping map = {
 		.window_type = ASPEED_LPC_CTRL_WINDOW_FLASH,
@@ -93,12 +93,12 @@
 
 /*
- * point_to_flash() - Point the lpc bus mapping to the actual flash device
+ * lpc_map_flash() - Point the lpc bus mapping to the actual flash device
  * @context:	The mbox context pointer
  *